y <- matrix(c(17066,14464,788,126,37,48,38,5,1,1,),ncol=2)
drinks <- c(0,0.5,1.5,4,7)

z <- log(y[,1]/y[,2])
w <- y[,1]*y[,2]/(y[,1]+y[,2])
A <- sum(w)
B <- sum(w*z)
C <- sum(w*drinks)
D <- sum(w*drinks^2)
E <- sum(w*drinks*z)

print(beta1 <- (E-B*C/A)/(D-C^2/A))
print(beta0 <- B/A-beta1*C/A)

summary(glm(y~1,family=binomial))
summary(z1 <- glm(y~drinks,family=binomial))

print(y[,1]/(y[,1]+y[,2]))
fitted(z1)

# logistic residuals
residuals(z1,type="pearson")
n <- y[,1]+y[,2]
print(r1 <- (y[,1]-n*fitted(z1))/sqrt(fitted(z1)*(1-fitted(z1))*n))
(y[,2]-n*(1-fitted(z1)))/sqrt(fitted(z1)*(1-fitted(z1))*n)
# log linear residuals
(y[,1]-n*fitted(z1))/sqrt(fitted(z1)*n)
(y[,2]-n*(1-fitted(z1)))/sqrt((1-fitted(z1))*n)

sum(r1^2)

if(interactive()){
postscript("malform.eps",height=6,width=6)
par(font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
x <- seq(0,7,by=0.1)
plot(drinks,y[,1]/(y[,1]+y[,2]),xlim=c(0,8),ylim=c(0.96,1),pch=4,
	xlab="Drinks per day",ylab=expression(pi))
lines(x,1/(1+exp(-z1$coef[1]-z1$coef[2]*x)))
legend(1,0.97,legend=c("Observed","Logistic regression"),pch=c(4,-1),
	lty=c(0,1),bty="n")
dev.off()
}

# Chapter 3
# intervals of precision

slope <- coef(z1)[2]
se <- coef(summary(z1))[2,2]
points <- seq(slope-3*se,slope+3*se,by=0.02)
lr <- rep(0,length(points))
for(i in 1:length(points)){
      lr[i] <- deviance(glm(y~1,family=binomial,offset=drinks*points[i]))}
lr <- exp(-(lr-deviance(z1))/2)

if(interactive()){
postscript("malform2.eps",height=6,width=6)
par(font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(points,exp(-(points-slope)^2/(2*se^2)),type="l",xlab=expression(beta[1]),
	ylab=expression(R(beta[1])),lty=2)
lines(points,lr)
lines(rep((2*points[9]+points[10])/3,2),c(0,exp(-1.96)))
lines(c((2*points[9]+points[10])/3,points[35]),rep(exp(-1.96),2))
lines(rep(points[35],2),c(0,exp(-1.96)))
lines(rep(slope+1.96*se,2),c(0,exp(-1.96)),lty=2)
lines(c(slope-1.96*se,slope+1.96*se),rep(exp(-1.96),2),lty=2)
lines(rep(slope-1.96*se,2),c(0,exp(-1.96)),lty=2)
lines(rep(points[12],2),c(0,exp(-1)),lty=3)
lines(c(points[12],points[30]),rep(exp(-1),2),lty=3)
lines(rep(points[30],2),c(0,exp(-1)),lty=3)
legend(-0.7,1,legend=c("Profile likelihood","Standard error",
	"  approximation"),lty=c(1,2,0),bty="n")
dev.off()
}
